@@ -646,7 +646,7 @@ ephyrRandRSetConfig(ScreenPtr pScreen,
         EPHYR_DBG("HAVE VIRTUAl SCREENS: %d, configured: %d",i,pScrPriv->numOutputs);
         for(;i<pScrPriv->numOutputs;++i)
         {
-            EPHYR_DBG("Disconnect virtual screen %d",i);
+            EPHYR_DBG("Disconnecting virtual screen %d",i);
             updateOutput(pScreen, pScrPriv->outputs[i],screen->width, screen->height, 0,0, FALSE, FALSE);
         }
     }
