@@ -2,7 +2,7 @@
  * X2GoKDrive - A kdrive X server for X2Go (based on Xephyr)
  *             Author Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>
  *
- * Copyright © 2018-2023 phoca-GmbH
+ * Copyright © 2018-2024 phoca-GmbH
  *
  *
  *
@@ -114,7 +114,8 @@
 #define DEFAULT_PORT 15000
 
 #define ACCEPT_TIMEOUT 30000 //msec
-#define CLIENTALIVE_TIMEOUT 30000 //msec
+#define CLIENTALIVE_TIMEOUT_GENERIC 30000 //msec
+#define CLIENTALIVE_TIMEOUT_WEB 120000 //msec
 #define SERVERALIVE_TIMEOUT 10 //sec
 
 //if true, will save compressed jpg in file
